import { LitElement } from 'lit';
import { ElementPin } from './pin';
export declare class SevenSegmentElement extends LitElement {
    /** The color of a lit segment */
    color: string;
    /** The color of an unlit segment */
    offColor: string;
    /** The background color of the 7-segment display */
    background: string;
    /** Number of digits to display (1, 2 or 4 are common values) */
    digits: number;
    /** Whether to show a colon (clock mode) */
    colon: boolean;
    /** Whether the colon is lit or not */
    colonValue: boolean;
    /**
     * Pin format. `top` to draw pins on top of the segment display panel,
     * `extend` to extend them to the sides of the panel, and `none` to
     * disable drawing the pins.
     */
    pins: 'top' | 'extend' | 'none';
    /**
     * The values for the individual segments. Each digit has 8
     * segment values in the following order: A, B, C, D, E, F, G, DP
     *
     * The values are 1 for a lit segment, and 0 for an unlit segment.
     */
    values: number[];
    get pinInfo(): ElementPin[];
    static get styles(): import("lit").CSSResult;
    private get pinPositions();
    private get yOffset();
    update(changedProperties: Map<string, unknown>): void;
    renderDigit(x: number, startIndex: number): import("lit-html").TemplateResult<2>;
    renderColon(): import("lit-html").TemplateResult<2>;
    renderPins(): import("lit-html").TemplateResult<2>;
    render(): import("lit-html").TemplateResult<1>;
}
