import { LitElement } from 'lit';
import { ElementPin } from './pin';
import { RGB } from './types/rgb';
export declare class LEDRingElement extends LitElement {
    /**
     * Number of pixels to in the LED ring
     */
    pixels: number;
    /**
     * Space between pixels (in mm)
     */
    pixelSpacing: number;
    /**
     * Background (PCB) color
     */
    background: string;
    /**
     * Animate the LEDs in the matrix. Used primarily for testing in Storybook.
     * The animation sequence is not guaranteed and may change in future releases of
     * this element.
     */
    animation: boolean;
    private pixelElements;
    private animationFrame;
    get radius(): number;
    get pinInfo(): ElementPin[];
    private getPixelElements;
    setPixel(pixel: number, { r, g, b }: RGB): void;
    /**
     * Resets all the pixels to off state (r=0, g=0, b=0).
     */
    reset(): void;
    private animateStep;
    update(changedProperties: Map<string, unknown>): void;
    updated(): void;
    render(): import("lit-html").TemplateResult<1>;
}
