"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getScreenCTM = void 0;
const geometry_1 = require("./geometry");
function getScreenCTM(target, workaroundElement, workaroundRect) {
    var _a, _b;
    const { userAgent } = navigator;
    const workaroundNeeded = userAgent.indexOf('Firefox') >= 0 ||
        userAgent.indexOf('Epiphany') >= 0 ||
        userAgent.indexOf('Safari') >= 0;
    if (workaroundNeeded) {
        // Firefox's getScreenCTM() is broken: https://bugzilla.mozilla.org/show_bug.cgi?id=1610093
        const targetCTM = target.getCTM();
        const workaroundCTM = workaroundElement === null || workaroundElement === void 0 ? void 0 : workaroundElement.getCTM();
        const boundingRect = workaroundElement === null || workaroundElement === void 0 ? void 0 : workaroundElement.getBoundingClientRect();
        const svgRect = (_a = workaroundElement === null || workaroundElement === void 0 ? void 0 : workaroundElement.ownerSVGElement) === null || _a === void 0 ? void 0 : _a.getBoundingClientRect();
        if (!boundingRect || !svgRect || !workaroundCTM || !targetCTM) {
            return null;
        }
        const centerX = svgRect.x + svgRect.width / 2;
        const centerY = svgRect.y + svgRect.height / 2;
        const deltaX = centerX - (boundingRect.x + boundingRect.width / 2);
        const deltaY = centerY - (boundingRect.y + boundingRect.height / 2);
        const angle = (Math.atan2(deltaY, deltaX) / Math.PI) * 180;
        const rotation = new DOMMatrix().rotate(angle);
        const rotatedRect = geometry_1.calculateBoundingRect(workaroundRect, rotation);
        const scaleX = rotatedRect.width / boundingRect.width;
        const scaleY = rotatedRect.height / boundingRect.height;
        const localCTM = workaroundCTM.inverse().multiply(targetCTM);
        return rotation
            .inverse()
            .translate(rotatedRect.left, rotatedRect.top)
            .multiply(localCTM.inverse())
            .scale(scaleX, scaleY)
            .translate(-boundingRect.left, -boundingRect.top);
    }
    else {
        return ((_b = target.getScreenCTM()) === null || _b === void 0 ? void 0 : _b.inverse()) || null;
    }
}
exports.getScreenCTM = getScreenCTM;
